@@ -1,8 +1,8 @@
 #
 assign("est.variogram",
-function(point.obj,pairs.obj,a1,a2) {
+function(point.obj,pair.obj,a1,a2) {
 
-#  est.variogram takes a "point" object, point.obj, and a "pairs" object, pairs.obj,
+#  est.variogram takes a "point" object, point.obj, and a "pair" object, pair.obj,
 #  calculates empirical variogram estimates.
 
 
@@ -18,7 +18,7 @@ function(point.obj,pairs.obj,a1,a2) {
 
   if (!inherits(point.obj,"point")) stop('Point.obj must be of class, "point".\n')
 
-  if (!inherits(pairs.obj,"pairs")) stop('Pairs.obj must be of class, "pairs".\n')
+  if (!inherits(pair.obj,"pair")) stop('Pair.obj must be of class, "pair".\n')
 
   if(missing(a1)) stop('Must enter at least one attribute.\n')
   if(missing(a2)) a2 <- a1
@@ -27,25 +27,25 @@ function(point.obj,pairs.obj,a1,a2) {
   a2 <- point.obj[[match(a2,names(point.obj))]]
 
 # Allocate some space...
-  lags    <- sort(unique(pairs.obj$lags))
+  lags    <- sort(unique(pair.obj$lags))
   classic <- rep(0,length(lags))
   robust  <- rep(0,length(lags))
   med     <- rep(0,length(lags))
   n       <- rep(0,length(lags))
 
-  diff <- a1[pairs.obj$from]-a2[pairs.obj$to]
-  bo   <- split(diff,pairs.obj$lags)
+  diff <- a1[pair.obj$from]-a2[pair.obj$to]
+  bo   <- split(diff,pair.obj$lags)
 
 # this fails sometimes:
-#  tmp<-unique(pairs.obj$lags[-which.na(pairs.obj$lags)])
+#  tmp<-unique(pair.obj$lags[-which.na(pair.obj$lags)])
 # so do this:
-  if (any(is.na(pairs.obj$lags))) 
-     tmp <- unique(pairs.obj$lags[-which.na(pairs.obj$lags)])
+  if (any(is.na(pair.obj$lags))) 
+     tmp <- unique(pair.obj$lags[-which.na(pair.obj$lags)])
   else 
-     tmp <- unique(pairs.obj$lags)
+     tmp <- unique(pair.obj$lags)
 
   for (i in c(1:length(tmp))) {
-#  for (i in unique(pairs.obj$lags)) {
+#  for (i in unique(pair.obj$lags)) {
     n[i] _ length(bo[[i]][!is.na(bo[[i]])])
 
 #   classic, see Matheron
@@ -56,7 +56,7 @@ function(point.obj,pairs.obj,a1,a2) {
     med[i] <- (median(abs(bo[[i]])^.5,na.rm=T))^4 / (0.457 + (0.494/n[i]))
 #    med[i] <- median(abs(bo[[i]]),na.rm=T)
   }    
-  o.variogram <- data.frame(lags,bins=c(pairs.obj$bins,recursive=T),classic,
+  o.variogram <- data.frame(lags,bins=c(pair.obj$bins,recursive=T),classic,
                       robust,med,n=n)
   class(o.variogram) <- c("variogram","data.frame")
   return(o.variogram)
